@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012 Vincent Jacques
-# vincent@vincent-jacques.net
+# Copyright 2012 Vincent Jacques vincent@vincent-jacques.net
+# Copyright 2012 Zearin zearin@gonk.net
+# Copyright 2013 Vincent Jacques vincent@vincent-jacques.net
 
 # This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
@@ -38,3 +39,19 @@ class Authentication(Framework.BasicTestCase):
     def testUserAgent(self):
         g = github.Github(user_agent="PyGithubTester")
         self.assertEqual(g.get_user("jacquev6").name, "Vincent Jacques")
+
+    def testAuthorizationHeaderWithLogin(self):
+        # See special case in Framework.fixAuthorizationHeader
+        g = github.Github("fake_login", "fake_password")
+        try:
+            g.get_user().name
+        except github.GithubException:
+            pass
+
+    def testAuthorizationHeaderWithToken(self):
+        # See special case in Framework.fixAuthorizationHeader
+        g = github.Github("ZmFrZV9sb2dpbjpmYWtlX3Bhc3N3b3Jk")
+        try:
+            g.get_user().name
+        except github.GithubException:
+            pass
